Option Explicit
Dim AlertCritical, AlertImportant, AlertModerate, AlertLow, AlertUnclassified, EmailFrom, EmailTo, SMTP_Server, SMTP_Port, SMTP_User, SMTP_Pass, SMTP_UseSSL
'==========================================================================
' NAME		: Windows update automatic e-mail notification
' AUTHOR	: Paulie@tachytelic.net
' DATE  	: 26/08/2007
' Updated	: 14/12/2018
' URL		: https://www.tachytelic.net/2007/08/windows-update-automatic-e-mail-notification
'==========================================================================
'
'Change these variables to control which updates trigger an e-mail alert (use 1 to enable an alert level or 0 to disable it)
AlertCritical = 1 						'
AlertImportant = 1
AlertModerate = 1
AlertLow = 0
AlertUnclassified = 0
'Change these variable to control the SMTP Settings
EmailFrom 		= ""
EmailTo 		= ""
'If SMTP Server is left empty it will try to use the local SMTP Server without auth
SMTP_Server		= ""
SMTP_Port		= ""
SMTP_User		= ""
SMTP_Pass		= ""
'Set this variable to 1 to enable SMTP over SSL
SMTP_UseSSL 	= "0"
'==========================================================================
'Don't change anything below this line unless you know what you are doing :D 

Dim fso, updateSession, updateSearcher, oShell, computername, DomainName, EmailSubject, searchResult
Set fso 			= CreateObject("Scripting.FileSystemObject")
Set updateSession 	= CreateObject("Microsoft.Update.Session")
Set updateSearcher 	= updateSession.CreateupdateSearcher()

Set oShell 		= CreateObject( "WScript.Shell" )
computername	= oShell.ExpandEnvironmentStrings("%ComputerName%")
DomainName		= oShell.ExpandEnvironmentStrings("%userdomain%")
EMailSubject 	= "Windows Update Notification - " & DomainName & "\" & computername
Set oshell 		= Nothing

Dim I, update, CriticalCount, CriticalHTML, ImportantCount, ImportantHTML, ModerateCount, ModerateHTML, Lowcount, LowHTML, UnclassifiedCount,UnclassifiedHMTL
CriticalCount=cInt(0)
ImportantCount=cInt(0)
ModerateCount=cInt(0)
LowCount=cInt(0)
UnclassifiedCount=cInt(0)

WScript.Echo "Checking for available updates..."
Set searchResult 	= updateSearcher.Search("IsInstalled=0 and Type='Software'")
If searchResult.Updates.count > 0 Then
	WScript.Echo searchResult.Updates.Count-1 & " Updates Found"
	For I = 0 To searchResult.Updates.Count-1
		
	    Set update = searchResult.Updates.Item(I)
		Select Case update.MsrcSeverity
			Case "Critical" 
				If AlertCritical = 1 then
					CriticalCount = Criticalcount+1
					CriticalHTML = CriticalHTML & MakeHTMLLine(update)
				end if
			Case "Important"
				if AlertImportant = 1 then
					ImportantCount = Importantcount + 1
					ImportantHTML = ImportantHTML & MakeHTMLLine(update)
				end if
			Case "Moderate"
				if AlertModerate = 1 then 
					ModerateCount = Moderatecount + 1
					ModerateHTML = ModerateHTML & MakeHTMLLine(update)
				end if
			Case "Low"
				if AlertLow = 1 then
					Lowcount = Lowcount + 1
					LowHTML = LowHTML & MakeHTMLLine(update)
				end if
			Case else
				If AlertUnclassified = 1 then
					UnclassifiedCount = UnclassifiedCount + 1
					UnclassifiedHMTL = UnclassifiedHMTL & MakeHTMLLine(update)
				end if
		end select			
	Next
	
	Dim SendEmail 
	If CriticalCount > 0 Or ImportantCount > 0 Or ModerateCount > 0 Or Lowcount > 0 Or UnclassifiedCount > 0 Then SendEmail=CBool(1)
	if SendEmail Then
		Dim objMessage, objConfig, Fields
		Set objMessage = CreateObject("CDO.Message") 
		Set objConfig = CreateObject("CDO.Configuration")
		Set Fields = objConfig.Fields
		if SMTP_Server <> "" Then
			With Fields
				.Item ("http://schemas.microsoft.com/cdo/configuration/sendusing") = 2 
				.Item ("http://schemas.microsoft.com/cdo/configuration/smtpserver") = SMTP_Server
				.Item ("http://schemas.microsoft.com/cdo/configuration/smtpserverport") = SMTP_Port
				.Item ("http://schemas.microsoft.com/cdo/configuration/smtpauthenticate") = 1
				if SMTP_User <> "" then
					.Item ("http://schemas.microsoft.com/cdo/configuration/sendusername") = SMTP_User
					.Item ("http://schemas.microsoft.com/cdo/configuration/sendpassword") = SMTP_Pass
				end if
				if SMTP_UseSSL = "1" then 
					.Item("http://schemas.microsoft.com/cdo/configuration/smtpusessl") = True
				end If
				.Update
			End With
			Set objMessage.Configuration = objConfig
		end if
		
		with objMessage
			.Subject = EMailSubject
			.From = EmailFrom
			.To = EmailTo
			.HTMLBody = ReplaceHTMLTemplate()
		end With
		On Error Resume Next
		objMessage.Send
		If Err.number <> 0 Then
			WScript.Echo "Failed to send email, the error was:"
			WScript.Echo err.Description
			WScript.Quit
		Else
			WScript.Echo "Email sent succesfully"
		End if
	else
		wscript.echo("Updates available for this system, but none matching the alert criteria. Quitting...")
	end if

End If

Function MakeHTMLLine(update)
	Dim HTMLLine, counter, Article, Info
	HTMLLine="<tr><td>" & update.Title & "</td><td>" & update.description & "</td><td>"
	counter	=0	
	For Each Article in Update.KBArticleIDs 
		 if counter > 0 then HTMLLine=HTMLLine & "<BR>"
        	 HTMLLine=HTMLLine & "<a href=" & chr(34) & "http://support.microsoft.com/kb/" & article & "/en-us" & chr(34) & ">KB" & article & "</a>"
		 counter = counter +1
    	Next 
	For Each Info in Update.moreinfourls 
		if counter > 0 then HTMLLine=HTMLLine & "<BR>"
		HTMLLine=HTMLLine & "<a href=" & chr(34) & info & chr(34) & ">" & "More information...</a>"
		counter = counter +1
    	Next 	
	HTMLLine = HTMLLine & "</td></tr>"
	MakeHTMLLine = HTMLLine
End function

Function ReplaceHTMLTemplate()
	Dim HTMLFile, MasterHTML
	Set HTMLFile = fso.opentextfile((fso.GetParentFolderName(WScript.ScriptFullName) & "\updatetemplate.htm"),1,false)
	MasterHTML = HTMLFile.Readall
	HTMLFile.close

	MasterHTML = Replace(MasterHTML, "[criticalupdatecontents]", CriticalHTML)
	MasterHTML = Replace(MasterHTML, "[importantupdatecontents]", ImportantHTML)
	MasterHTML = Replace(MasterHTML, "[moderateupdatecontents]", ModerateHTML)
	MasterHTML = Replace(MasterHTML, "[lowupdatecontents]", LowHTML)
	MasterHTML = Replace(MasterHTML, "[unclassifiedupdatecontents]", UnclassifiedHMTL)
	MasterHTML = Replace(MasterHTML, "[computername]", Computername)
	MasterHTML = Replace(MasterHTML, "[domainname]", domainname)
	MasterHTML = Replace(MasterHTML, "[timenow]", FormatDateTime(Now(),1) & " " & FormatDateTime(Now(),4))
	
	If (CriticalCount = 0) then
        	MasterHTML = TrimSection(MasterHTML, "<!--CriticalStart-->", "<!--CriticalEnd-->")
	end if
	If (ImportantCount = 0) then
	        MasterHTML = TrimSection(MasterHTML, "<!--ImportantStart-->", "<!--ImportantEnd-->")
    end if
    If (moderateCount = 0) then
        	MasterHTML = TrimSection(MasterHTML, "<!--ModerateStart-->", "<!--ModerateEnd-->")
    end if
	If (LowCount = 0) then	
        	MasterHTML = TrimSection(MasterHTML, "<!--LowStart-->", "<!--LowEnd-->")
    end if
	If (UnclassifiedCount = 0) then	
        	MasterHTML = TrimSection(MasterHTML, "<!--UnclassfiedStart-->", "<!--UnclassifiedEnd-->")
    end if
    ReplaceHTMLTemplate = MasterHTML	    
End Function

Function TrimSection(CompleteString,LeftString,RightString)
	Dim Reg :Set Reg = New RegExp
	Reg.Pattern = LeftString & ".*((.|\n)*)" & RightString
	If Reg.Test(CompleteString) Then
		TrimSection = Reg.Replace(CompleteString, "")
	End If
End Function